# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegistrationCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkMultiResolutionImageRegistrationMethodPython
else:
    import _itkMultiResolutionImageRegistrationMethodPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkImageToImageMetricPython
import itk.itkSpatialObjectBasePython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
import itk.itkArrayPython
import itk.itkSpatialObjectPropertyPython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.itkArray2DPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkInterpolateImageFunctionPython
import itk.itkImageFunctionBasePython
import itk.itkFunctionBasePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.ITKCostFunctionsPython
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
import itk.vnl_least_squares_functionPython
import itk.itkCostFunctionPython
import itk.itkMultiResolutionPyramidImageFilterPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkImageToImageFilterCommonPython
import itk.ITKOptimizersBasePython

def itkMultiResolutionImageRegistrationMethodIF2IF2_New():
    return itkMultiResolutionImageRegistrationMethodIF2IF2.New()

class itkMultiResolutionImageRegistrationMethodIF2IF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMultiResolutionImageRegistrationMethodIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiResolutionImageRegistrationMethodIF2IF2_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiResolutionImageRegistrationMethodIF2IF2_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_Clone(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_StopRegistration(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF2 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIF2IF2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIF2IF2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIF2IF2
        GetMetric(self) -> itkImageToImageMetricIF2IF2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetMetric(self, *args)

    def SetFixedImageRegion(self, _arg):
        r"""
        SetFixedImageRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion2

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetFixedImageRegion(self, _arg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetFixedImageRegion(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF2D *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF2D"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetInterpolator(self, *args)

    def SetFixedImagePyramid(self, _arg):
        r"""
        SetFixedImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIF2IF2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetFixedImagePyramid(self, _arg)

    def GetModifiableFixedImagePyramid(self):
        r"""GetModifiableFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF2IF2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetModifiableFixedImagePyramid(self)

    def GetFixedImagePyramid(self, *args):
        r"""
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF2IF2
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF2IF2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetFixedImagePyramid(self, *args)

    def SetMovingImagePyramid(self, _arg):
        r"""
        SetMovingImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIF2IF2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetMovingImagePyramid(self, _arg)

    def GetModifiableMovingImagePyramid(self):
        r"""GetModifiableMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF2IF2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetModifiableMovingImagePyramid(self)

    def GetMovingImagePyramid(self, *args):
        r"""
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF2IF2
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF2IF2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetMovingImagePyramid(self, *args)

    def SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule):
        r"""
        SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

        Parameters
        ----------
        fixedImagePyramidSchedule: itkArray2DUI const &
        movingImagePyramidSchedule: itkArray2DUI const &

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

    def GetFixedImagePyramidSchedule(self):
        r"""GetFixedImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetFixedImagePyramidSchedule(self)

    def GetMovingImagePyramidSchedule(self):
        r"""GetMovingImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetMovingImagePyramidSchedule(self)

    def SetNumberOfLevels(self, numberOfLevels):
        r"""
        SetNumberOfLevels(self, numberOfLevels)

        Parameters
        ----------
        numberOfLevels: unsigned long

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetNumberOfLevels(self, numberOfLevels)

    def GetNumberOfLevels(self):
        r"""GetNumberOfLevels(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetNumberOfLevels(self)

    def GetCurrentLevel(self):
        r"""GetCurrentLevel(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetCurrentLevel(self)

    def SetInitialTransformParameters(self, _arg):
        r"""
        SetInitialTransformParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetInitialTransformParameters(self, _arg)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetInitialTransformParameters(self)

    def SetInitialTransformParametersOfNextLevel(self, _arg):
        r"""
        SetInitialTransformParametersOfNextLevel(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_SetInitialTransformParametersOfNextLevel(self, _arg)

    def GetInitialTransformParametersOfNextLevel(self):
        r"""GetInitialTransformParametersOfNextLevel(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetInitialTransformParametersOfNextLevel(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetLastTransformParameters(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD22"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_GetOutput(self)
    __swig_destroy__ = _itkMultiResolutionImageRegistrationMethodPython.delete_itkMultiResolutionImageRegistrationMethodIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiResolutionImageRegistrationMethodIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiResolutionImageRegistrationMethodIF2IF2

        Create a new object of the class itkMultiResolutionImageRegistrationMethodIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiResolutionImageRegistrationMethodIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiResolutionImageRegistrationMethodIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiResolutionImageRegistrationMethodIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiResolutionImageRegistrationMethodIF2IF2 in _itkMultiResolutionImageRegistrationMethodPython:
_itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF2IF2_swigregister(itkMultiResolutionImageRegistrationMethodIF2IF2)

def itkMultiResolutionImageRegistrationMethodIF3IF3_New():
    return itkMultiResolutionImageRegistrationMethodIF3IF3.New()

class itkMultiResolutionImageRegistrationMethodIF3IF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMultiResolutionImageRegistrationMethodIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiResolutionImageRegistrationMethodIF3IF3_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiResolutionImageRegistrationMethodIF3IF3_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_Clone(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_StopRegistration(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageF3 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIF3IF3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIF3IF3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIF3IF3
        GetMetric(self) -> itkImageToImageMetricIF3IF3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetMetric(self, *args)

    def SetFixedImageRegion(self, _arg):
        r"""
        SetFixedImageRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion3

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetFixedImageRegion(self, _arg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetFixedImageRegion(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF3D *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF3D"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetInterpolator(self, *args)

    def SetFixedImagePyramid(self, _arg):
        r"""
        SetFixedImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIF3IF3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetFixedImagePyramid(self, _arg)

    def GetModifiableFixedImagePyramid(self):
        r"""GetModifiableFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF3IF3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetModifiableFixedImagePyramid(self)

    def GetFixedImagePyramid(self, *args):
        r"""
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF3IF3
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF3IF3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetFixedImagePyramid(self, *args)

    def SetMovingImagePyramid(self, _arg):
        r"""
        SetMovingImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIF3IF3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetMovingImagePyramid(self, _arg)

    def GetModifiableMovingImagePyramid(self):
        r"""GetModifiableMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF3IF3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetModifiableMovingImagePyramid(self)

    def GetMovingImagePyramid(self, *args):
        r"""
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF3IF3
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIF3IF3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetMovingImagePyramid(self, *args)

    def SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule):
        r"""
        SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

        Parameters
        ----------
        fixedImagePyramidSchedule: itkArray2DUI const &
        movingImagePyramidSchedule: itkArray2DUI const &

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

    def GetFixedImagePyramidSchedule(self):
        r"""GetFixedImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetFixedImagePyramidSchedule(self)

    def GetMovingImagePyramidSchedule(self):
        r"""GetMovingImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetMovingImagePyramidSchedule(self)

    def SetNumberOfLevels(self, numberOfLevels):
        r"""
        SetNumberOfLevels(self, numberOfLevels)

        Parameters
        ----------
        numberOfLevels: unsigned long

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetNumberOfLevels(self, numberOfLevels)

    def GetNumberOfLevels(self):
        r"""GetNumberOfLevels(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetNumberOfLevels(self)

    def GetCurrentLevel(self):
        r"""GetCurrentLevel(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetCurrentLevel(self)

    def SetInitialTransformParameters(self, _arg):
        r"""
        SetInitialTransformParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetInitialTransformParameters(self, _arg)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetInitialTransformParameters(self)

    def SetInitialTransformParametersOfNextLevel(self, _arg):
        r"""
        SetInitialTransformParametersOfNextLevel(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_SetInitialTransformParametersOfNextLevel(self, _arg)

    def GetInitialTransformParametersOfNextLevel(self):
        r"""GetInitialTransformParametersOfNextLevel(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetInitialTransformParametersOfNextLevel(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetLastTransformParameters(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD33"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_GetOutput(self)
    __swig_destroy__ = _itkMultiResolutionImageRegistrationMethodPython.delete_itkMultiResolutionImageRegistrationMethodIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiResolutionImageRegistrationMethodIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiResolutionImageRegistrationMethodIF3IF3

        Create a new object of the class itkMultiResolutionImageRegistrationMethodIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiResolutionImageRegistrationMethodIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiResolutionImageRegistrationMethodIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiResolutionImageRegistrationMethodIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiResolutionImageRegistrationMethodIF3IF3 in _itkMultiResolutionImageRegistrationMethodPython:
_itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIF3IF3_swigregister(itkMultiResolutionImageRegistrationMethodIF3IF3)

def itkMultiResolutionImageRegistrationMethodISS2ISS2_New():
    return itkMultiResolutionImageRegistrationMethodISS2ISS2.New()

class itkMultiResolutionImageRegistrationMethodISS2ISS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMultiResolutionImageRegistrationMethodISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiResolutionImageRegistrationMethodISS2ISS2_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiResolutionImageRegistrationMethodISS2ISS2_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_Clone(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_StopRegistration(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricISS2ISS2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricISS2ISS2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricISS2ISS2
        GetMetric(self) -> itkImageToImageMetricISS2ISS2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetMetric(self, *args)

    def SetFixedImageRegion(self, _arg):
        r"""
        SetFixedImageRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion2

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetFixedImageRegion(self, _arg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetFixedImageRegion(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS2D *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS2D"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetInterpolator(self, *args)

    def SetFixedImagePyramid(self, _arg):
        r"""
        SetFixedImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterISS2ISS2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetFixedImagePyramid(self, _arg)

    def GetModifiableFixedImagePyramid(self):
        r"""GetModifiableFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS2ISS2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetModifiableFixedImagePyramid(self)

    def GetFixedImagePyramid(self, *args):
        r"""
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS2ISS2
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS2ISS2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetFixedImagePyramid(self, *args)

    def SetMovingImagePyramid(self, _arg):
        r"""
        SetMovingImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterISS2ISS2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetMovingImagePyramid(self, _arg)

    def GetModifiableMovingImagePyramid(self):
        r"""GetModifiableMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS2ISS2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetModifiableMovingImagePyramid(self)

    def GetMovingImagePyramid(self, *args):
        r"""
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS2ISS2
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS2ISS2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetMovingImagePyramid(self, *args)

    def SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule):
        r"""
        SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

        Parameters
        ----------
        fixedImagePyramidSchedule: itkArray2DUI const &
        movingImagePyramidSchedule: itkArray2DUI const &

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

    def GetFixedImagePyramidSchedule(self):
        r"""GetFixedImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetFixedImagePyramidSchedule(self)

    def GetMovingImagePyramidSchedule(self):
        r"""GetMovingImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetMovingImagePyramidSchedule(self)

    def SetNumberOfLevels(self, numberOfLevels):
        r"""
        SetNumberOfLevels(self, numberOfLevels)

        Parameters
        ----------
        numberOfLevels: unsigned long

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetNumberOfLevels(self, numberOfLevels)

    def GetNumberOfLevels(self):
        r"""GetNumberOfLevels(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetNumberOfLevels(self)

    def GetCurrentLevel(self):
        r"""GetCurrentLevel(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetCurrentLevel(self)

    def SetInitialTransformParameters(self, _arg):
        r"""
        SetInitialTransformParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetInitialTransformParameters(self, _arg)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetInitialTransformParameters(self)

    def SetInitialTransformParametersOfNextLevel(self, _arg):
        r"""
        SetInitialTransformParametersOfNextLevel(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_SetInitialTransformParametersOfNextLevel(self, _arg)

    def GetInitialTransformParametersOfNextLevel(self):
        r"""GetInitialTransformParametersOfNextLevel(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetInitialTransformParametersOfNextLevel(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetLastTransformParameters(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD22"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_GetOutput(self)
    __swig_destroy__ = _itkMultiResolutionImageRegistrationMethodPython.delete_itkMultiResolutionImageRegistrationMethodISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiResolutionImageRegistrationMethodISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiResolutionImageRegistrationMethodISS2ISS2

        Create a new object of the class itkMultiResolutionImageRegistrationMethodISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiResolutionImageRegistrationMethodISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiResolutionImageRegistrationMethodISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiResolutionImageRegistrationMethodISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiResolutionImageRegistrationMethodISS2ISS2 in _itkMultiResolutionImageRegistrationMethodPython:
_itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS2ISS2_swigregister(itkMultiResolutionImageRegistrationMethodISS2ISS2)

def itkMultiResolutionImageRegistrationMethodISS3ISS3_New():
    return itkMultiResolutionImageRegistrationMethodISS3ISS3.New()

class itkMultiResolutionImageRegistrationMethodISS3ISS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMultiResolutionImageRegistrationMethodISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiResolutionImageRegistrationMethodISS3ISS3_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiResolutionImageRegistrationMethodISS3ISS3_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_Clone(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_StopRegistration(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricISS3ISS3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricISS3ISS3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricISS3ISS3
        GetMetric(self) -> itkImageToImageMetricISS3ISS3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetMetric(self, *args)

    def SetFixedImageRegion(self, _arg):
        r"""
        SetFixedImageRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion3

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetFixedImageRegion(self, _arg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetFixedImageRegion(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS3D *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS3D"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetInterpolator(self, *args)

    def SetFixedImagePyramid(self, _arg):
        r"""
        SetFixedImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterISS3ISS3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetFixedImagePyramid(self, _arg)

    def GetModifiableFixedImagePyramid(self):
        r"""GetModifiableFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS3ISS3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetModifiableFixedImagePyramid(self)

    def GetFixedImagePyramid(self, *args):
        r"""
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS3ISS3
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS3ISS3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetFixedImagePyramid(self, *args)

    def SetMovingImagePyramid(self, _arg):
        r"""
        SetMovingImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterISS3ISS3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetMovingImagePyramid(self, _arg)

    def GetModifiableMovingImagePyramid(self):
        r"""GetModifiableMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS3ISS3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetModifiableMovingImagePyramid(self)

    def GetMovingImagePyramid(self, *args):
        r"""
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS3ISS3
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterISS3ISS3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetMovingImagePyramid(self, *args)

    def SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule):
        r"""
        SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

        Parameters
        ----------
        fixedImagePyramidSchedule: itkArray2DUI const &
        movingImagePyramidSchedule: itkArray2DUI const &

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

    def GetFixedImagePyramidSchedule(self):
        r"""GetFixedImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetFixedImagePyramidSchedule(self)

    def GetMovingImagePyramidSchedule(self):
        r"""GetMovingImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetMovingImagePyramidSchedule(self)

    def SetNumberOfLevels(self, numberOfLevels):
        r"""
        SetNumberOfLevels(self, numberOfLevels)

        Parameters
        ----------
        numberOfLevels: unsigned long

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetNumberOfLevels(self, numberOfLevels)

    def GetNumberOfLevels(self):
        r"""GetNumberOfLevels(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetNumberOfLevels(self)

    def GetCurrentLevel(self):
        r"""GetCurrentLevel(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetCurrentLevel(self)

    def SetInitialTransformParameters(self, _arg):
        r"""
        SetInitialTransformParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetInitialTransformParameters(self, _arg)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetInitialTransformParameters(self)

    def SetInitialTransformParametersOfNextLevel(self, _arg):
        r"""
        SetInitialTransformParametersOfNextLevel(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_SetInitialTransformParametersOfNextLevel(self, _arg)

    def GetInitialTransformParametersOfNextLevel(self):
        r"""GetInitialTransformParametersOfNextLevel(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetInitialTransformParametersOfNextLevel(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetLastTransformParameters(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD33"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_GetOutput(self)
    __swig_destroy__ = _itkMultiResolutionImageRegistrationMethodPython.delete_itkMultiResolutionImageRegistrationMethodISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiResolutionImageRegistrationMethodISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiResolutionImageRegistrationMethodISS3ISS3

        Create a new object of the class itkMultiResolutionImageRegistrationMethodISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiResolutionImageRegistrationMethodISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiResolutionImageRegistrationMethodISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiResolutionImageRegistrationMethodISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiResolutionImageRegistrationMethodISS3ISS3 in _itkMultiResolutionImageRegistrationMethodPython:
_itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodISS3ISS3_swigregister(itkMultiResolutionImageRegistrationMethodISS3ISS3)

def itkMultiResolutionImageRegistrationMethodIUC2IUC2_New():
    return itkMultiResolutionImageRegistrationMethodIUC2IUC2.New()

class itkMultiResolutionImageRegistrationMethodIUC2IUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMultiResolutionImageRegistrationMethodIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiResolutionImageRegistrationMethodIUC2IUC2_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiResolutionImageRegistrationMethodIUC2IUC2_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_Clone(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_StopRegistration(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIUC2IUC2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIUC2IUC2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIUC2IUC2
        GetMetric(self) -> itkImageToImageMetricIUC2IUC2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetMetric(self, *args)

    def SetFixedImageRegion(self, _arg):
        r"""
        SetFixedImageRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion2

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetFixedImageRegion(self, _arg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetFixedImageRegion(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC2D *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC2D"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetInterpolator(self, *args)

    def SetFixedImagePyramid(self, _arg):
        r"""
        SetFixedImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIUC2IUC2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetFixedImagePyramid(self, _arg)

    def GetModifiableFixedImagePyramid(self):
        r"""GetModifiableFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC2IUC2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetModifiableFixedImagePyramid(self)

    def GetFixedImagePyramid(self, *args):
        r"""
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC2IUC2
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC2IUC2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetFixedImagePyramid(self, *args)

    def SetMovingImagePyramid(self, _arg):
        r"""
        SetMovingImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIUC2IUC2 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetMovingImagePyramid(self, _arg)

    def GetModifiableMovingImagePyramid(self):
        r"""GetModifiableMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC2IUC2"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetModifiableMovingImagePyramid(self)

    def GetMovingImagePyramid(self, *args):
        r"""
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC2IUC2
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC2IUC2
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetMovingImagePyramid(self, *args)

    def SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule):
        r"""
        SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

        Parameters
        ----------
        fixedImagePyramidSchedule: itkArray2DUI const &
        movingImagePyramidSchedule: itkArray2DUI const &

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

    def GetFixedImagePyramidSchedule(self):
        r"""GetFixedImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetFixedImagePyramidSchedule(self)

    def GetMovingImagePyramidSchedule(self):
        r"""GetMovingImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetMovingImagePyramidSchedule(self)

    def SetNumberOfLevels(self, numberOfLevels):
        r"""
        SetNumberOfLevels(self, numberOfLevels)

        Parameters
        ----------
        numberOfLevels: unsigned long

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetNumberOfLevels(self, numberOfLevels)

    def GetNumberOfLevels(self):
        r"""GetNumberOfLevels(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetNumberOfLevels(self)

    def GetCurrentLevel(self):
        r"""GetCurrentLevel(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetCurrentLevel(self)

    def SetInitialTransformParameters(self, _arg):
        r"""
        SetInitialTransformParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetInitialTransformParameters(self, _arg)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetInitialTransformParameters(self)

    def SetInitialTransformParametersOfNextLevel(self, _arg):
        r"""
        SetInitialTransformParametersOfNextLevel(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_SetInitialTransformParametersOfNextLevel(self, _arg)

    def GetInitialTransformParametersOfNextLevel(self):
        r"""GetInitialTransformParametersOfNextLevel(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetInitialTransformParametersOfNextLevel(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetLastTransformParameters(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD22"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_GetOutput(self)
    __swig_destroy__ = _itkMultiResolutionImageRegistrationMethodPython.delete_itkMultiResolutionImageRegistrationMethodIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiResolutionImageRegistrationMethodIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiResolutionImageRegistrationMethodIUC2IUC2

        Create a new object of the class itkMultiResolutionImageRegistrationMethodIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiResolutionImageRegistrationMethodIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiResolutionImageRegistrationMethodIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiResolutionImageRegistrationMethodIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiResolutionImageRegistrationMethodIUC2IUC2 in _itkMultiResolutionImageRegistrationMethodPython:
_itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC2IUC2_swigregister(itkMultiResolutionImageRegistrationMethodIUC2IUC2)

def itkMultiResolutionImageRegistrationMethodIUC3IUC3_New():
    return itkMultiResolutionImageRegistrationMethodIUC3IUC3.New()

class itkMultiResolutionImageRegistrationMethodIUC3IUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkMultiResolutionImageRegistrationMethodIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiResolutionImageRegistrationMethodIUC3IUC3_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiResolutionImageRegistrationMethodIUC3IUC3_Pointer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_Clone(self)

    def StopRegistration(self):
        r"""StopRegistration(self)"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_StopRegistration(self)

    def SetFixedImage(self, _arg):
        r"""
        SetFixedImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetFixedImage(self, _arg)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetFixedImage(self)

    def SetMovingImage(self, _arg):
        r"""
        SetMovingImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetMovingImage(self, _arg)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIUC3IUC3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIUC3IUC3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIUC3IUC3
        GetMetric(self) -> itkImageToImageMetricIUC3IUC3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetMetric(self, *args)

    def SetFixedImageRegion(self, _arg):
        r"""
        SetFixedImageRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion3

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetFixedImageRegion(self, _arg)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetFixedImageRegion(self)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC3D *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC3D"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetInterpolator(self, *args)

    def SetFixedImagePyramid(self, _arg):
        r"""
        SetFixedImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIUC3IUC3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetFixedImagePyramid(self, _arg)

    def GetModifiableFixedImagePyramid(self):
        r"""GetModifiableFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC3IUC3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetModifiableFixedImagePyramid(self)

    def GetFixedImagePyramid(self, *args):
        r"""
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC3IUC3
        GetFixedImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC3IUC3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetFixedImagePyramid(self, *args)

    def SetMovingImagePyramid(self, _arg):
        r"""
        SetMovingImagePyramid(self, _arg)

        Parameters
        ----------
        _arg: itkMultiResolutionPyramidImageFilterIUC3IUC3 *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetMovingImagePyramid(self, _arg)

    def GetModifiableMovingImagePyramid(self):
        r"""GetModifiableMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC3IUC3"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetModifiableMovingImagePyramid(self)

    def GetMovingImagePyramid(self, *args):
        r"""
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC3IUC3
        GetMovingImagePyramid(self) -> itkMultiResolutionPyramidImageFilterIUC3IUC3
        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetMovingImagePyramid(self, *args)

    def SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule):
        r"""
        SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

        Parameters
        ----------
        fixedImagePyramidSchedule: itkArray2DUI const &
        movingImagePyramidSchedule: itkArray2DUI const &

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetSchedules(self, fixedImagePyramidSchedule, movingImagePyramidSchedule)

    def GetFixedImagePyramidSchedule(self):
        r"""GetFixedImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetFixedImagePyramidSchedule(self)

    def GetMovingImagePyramidSchedule(self):
        r"""GetMovingImagePyramidSchedule(self) -> itkArray2DUI"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetMovingImagePyramidSchedule(self)

    def SetNumberOfLevels(self, numberOfLevels):
        r"""
        SetNumberOfLevels(self, numberOfLevels)

        Parameters
        ----------
        numberOfLevels: unsigned long

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetNumberOfLevels(self, numberOfLevels)

    def GetNumberOfLevels(self):
        r"""GetNumberOfLevels(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetNumberOfLevels(self)

    def GetCurrentLevel(self):
        r"""GetCurrentLevel(self) -> unsigned long"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetCurrentLevel(self)

    def SetInitialTransformParameters(self, _arg):
        r"""
        SetInitialTransformParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetInitialTransformParameters(self, _arg)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetInitialTransformParameters(self)

    def SetInitialTransformParametersOfNextLevel(self, _arg):
        r"""
        SetInitialTransformParametersOfNextLevel(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_SetInitialTransformParametersOfNextLevel(self, _arg)

    def GetInitialTransformParametersOfNextLevel(self):
        r"""GetInitialTransformParametersOfNextLevel(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetInitialTransformParametersOfNextLevel(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetLastTransformParameters(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD33"""
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_GetOutput(self)
    __swig_destroy__ = _itkMultiResolutionImageRegistrationMethodPython.delete_itkMultiResolutionImageRegistrationMethodIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiResolutionImageRegistrationMethodIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiResolutionImageRegistrationMethodIUC3IUC3

        Create a new object of the class itkMultiResolutionImageRegistrationMethodIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiResolutionImageRegistrationMethodIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiResolutionImageRegistrationMethodIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiResolutionImageRegistrationMethodIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiResolutionImageRegistrationMethodIUC3IUC3 in _itkMultiResolutionImageRegistrationMethodPython:
_itkMultiResolutionImageRegistrationMethodPython.itkMultiResolutionImageRegistrationMethodIUC3IUC3_swigregister(itkMultiResolutionImageRegistrationMethodIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def multi_resolution_image_registration_method(*args,  fixed_image: itkt.Image=..., moving_image: itkt.Image=..., optimizer=..., metric=..., fixed_image_region: itkt.ImageRegion=..., transform: itkt.Transform=..., interpolator: itkt.InterpolateImageFunction=..., fixed_image_pyramid=..., moving_image_pyramid=..., schedules=..., number_of_levels: int=..., initial_transform_parameters=..., initial_transform_parameters_of_next_level=...,**kwargs):
    """Functional interface for MultiResolutionImageRegistrationMethod"""
    import itk

    kwarg_typehints = { 'fixed_image':fixed_image,'moving_image':moving_image,'optimizer':optimizer,'metric':metric,'fixed_image_region':fixed_image_region,'transform':transform,'interpolator':interpolator,'fixed_image_pyramid':fixed_image_pyramid,'moving_image_pyramid':moving_image_pyramid,'schedules':schedules,'number_of_levels':number_of_levels,'initial_transform_parameters':initial_transform_parameters,'initial_transform_parameters_of_next_level':initial_transform_parameters_of_next_level }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.MultiResolutionImageRegistrationMethod.New(*args, **kwargs)

    return instance.__internal_call__()

def multi_resolution_image_registration_method_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKRegistrationCommon.MultiResolutionImageRegistrationMethod
    multi_resolution_image_registration_method.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    multi_resolution_image_registration_method.__doc__ = filter_object.__doc__



